pub struct SignerRegistrationParameters {
pub party_id: Option<ProtocolPartyId>,
pub operational_certificate: Option<ProtocolOpCert>,
pub verification_key_for_concatenation: ProtocolSignerVerificationKeyForConcatenation,
pub verification_key_signature_for_concatenation: Option<ProtocolSignerVerificationKeySignatureForConcatenation>,
pub kes_evolutions: Option<KesEvolutions>,
pub verification_key_for_snark: Option<ProtocolSignerVerificationKeyForSnark>,
pub verification_key_signature_for_snark: Option<ProtocolSignerVerificationKeySignatureForSnark>,
}Expand description
Parameters required for registering a signer with the key registration service.
Groups the verification keys, their KES signatures, and the operational certificate that together prove a signer’s identity and authorization.
Fields
party_id: Option<ProtocolPartyId>The party identifier of the signer
Used only for testing when SPO pool id is not certified
operational_certificate: Option<ProtocolOpCert>The operational certificate of the stake pool operator
Used only for testing when SPO pool id is not certified
verification_key_for_concatenation: ProtocolSignerVerificationKeyForConcatenationThe verification key for the Concatenation proof system
verification_key_signature_for_concatenation: Option<ProtocolSignerVerificationKeySignatureForConcatenation>The KES signature over the verification key for Concatenation
None is used only for testing when SPO pool id is not certified
kes_evolutions: Option<KesEvolutions>The number of evolutions of the KES key since the start KES period of the operational certificate at the time of signature
verification_key_for_snark: Option<ProtocolSignerVerificationKeyForSnark>The verification key for the SNARK proof system
verification_key_signature_for_snark: Option<ProtocolSignerVerificationKeySignatureForSnark>The KES signature over the verification key for SNARK